TWMonthView class

Inheritance

Constructors

TWMonthView({Key? key, List<DateTime>? notSerialSelectedTimes, DateTime? selectStartDateTime, DateTime? selectEndDateTime, bool isMaxSelectedDays = false, bool isMinSelectedDays = false, required BuildContext context, required int year, required int month, required void onSelectDayRang(DateTime selectedDate), required DateTime firstDate, required DateTime lastDate, required TWCalendarConfigs? configs})
const

Properties

configs TWCalendarConfigs?
配置样式对象
final
context BuildContext
final
firstDate DateTime
开始的年月份
final
hashCode int
The hash code for this object.
no setterinherited
isMaxSelectedDays bool
是否超过最大选择天数
final
isMinSelectedDays bool
是否未低于最小选择天数
final
itemWidth double
no setter
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lastDate DateTime
结束的年月份
final
month int
final
notSerialSelectedTimes List<DateTime>?
final
onSelectDayRang → void Function(DateTime selectedDate)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectEndDateTime DateTime?
final
selectStartDateTime DateTime?
final
year int
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() TWMonthViewState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited