TWCalendarTool class

Constructors

TWCalendarTool()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

today DateTime
no setter
tomorrow DateTime
no setter

Static Methods

dateIsBetweenIn(DateTime date, DateTime firstDate, DateTime lastDate) bool
在过去和未来直接
dateIsToday(DateTime date) bool
formatPadLeft(int number, {int count = 2}) String
getDayNumberSize(BuildContext context, double padding) double
getDaysInMonth(int year, int month) int
getMonthName(int month, {List<String>? monthNames}) String
getSelectedDays(DateTime? selectStartTime, DateTime? selectEndTime) int
选择天数
getSelectedDaysTitle(DateTime? selectStartTime, DateTime? selectEndTime) String?
选择标题
getYearName(int year) String
isSameDate(DateTime firstDate, DateTime secondDate) bool